@@ -6,8 +6,8 @@
 #   copyright and license terms.
 #
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""
-"""
+""" """
+
 from __future__ import annotations
 
 __docformat__ = "restructuredtext"
@@ -15,7 +15,7 @@ __docformat__ = "restructuredtext"
 import argparse
 import re
 import sys
-from typing import Any, Pattern
+from typing import Any
 
 from ..utils import is_interactive
 
@@ -24,8 +24,8 @@ class HelpAction(argparse.Action):
     def __call__(
         self,
         parser: argparse.ArgumentParser,
-        namespace: argparse.Namespace,  # noqa: U100
-        values,  # noqa: U100
+        namespace: argparse.Namespace,
+        values,
         option_string: str | None = None,
     ) -> None:
         # import pydb; pydb.debugger()
@@ -36,7 +36,7 @@ class HelpAction(argparse.Action):
                 import subprocess
 
                 subprocess.check_call(
-                    "man %s 2> /dev/null" % parser.prog.replace(" ", "-"),
+                    "man {} 2> /dev/null".format(parser.prog.replace(" ", "-")),
                     shell=True,
                 )
                 sys.exit(0)
@@ -44,7 +44,7 @@ class HelpAction(argparse.Action):
                 # ...but silently fall back if it doesn't work
                 pass
         if option_string == "-h":
-            helpstr = "%s\n%s" % (
+            helpstr = "{}\n{}".format(
                 parser.format_usage(),
                 "Use '--help' to get more comprehensive information.",
             )
@@ -65,7 +65,7 @@ class HelpAction(argparse.Action):
             usagestr = re.split(r"\n\n[A-Z]+", helpstr, maxsplit=1)[0]
             usage_length = len(usagestr)
             usagestr = re.subn(r"\s+", " ", usagestr.replace("\n", " "))[0]
-            helpstr = "{}\n{}".format(usagestr, helpstr[usage_length:])
+            helpstr = f"{usagestr}\n{helpstr[usage_length:]}"
         print(helpstr)
         sys.exit(0)
 
@@ -73,10 +73,10 @@ class HelpAction(argparse.Action):
 class LogLevelAction(argparse.Action):
     def __call__(
         self,
-        parser: argparse.ArgumentParser,  # noqa: U100
-        namespace: argparse.Namespace,  # noqa: U100
+        parser: argparse.ArgumentParser,
+        namespace: argparse.Namespace,
         values,
-        option_string: str | None = None,  # noqa: U100
+        option_string: str | None = None,
     ) -> None:
         from ..log import LoggerHelper
 
@@ -122,7 +122,7 @@ class RegexpType:
     but we might provide a mode where we operate solely from cmdline
     """
 
-    def __call__(self, string: str | None) -> Pattern[str] | None:
+    def __call__(self, string: str | None) -> re.Pattern[str] | None:
         if string:
             return re.compile(string)
         else:
