@@ -7,14 +7,14 @@
 #
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Citation and citations Collector classes"""
+
 from __future__ import annotations
 
-from collections import namedtuple
 from functools import wraps
 import logging
 import os
 import sys
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, NamedTuple
 
 from .config import DUECREDIT_FILE
 from .entries import DueCreditEntry
@@ -27,7 +27,10 @@ lgr = logging.getLogger("duecredit.collector")
 if TYPE_CHECKING:
     from typing_extensions import Self
 
-CitationKey = namedtuple("CitationKey", ["path", "entry_key"])
+
+class CitationKey(NamedTuple):
+    path: str
+    entry_key: str
 
 
 class Citation:
@@ -93,11 +96,11 @@ class Citation:
     def __repr__(self) -> str:
         argl = [repr(self._entry)]
         if self._description:
-            argl.append(f"description={repr(self._description)}")
+            argl.append(f"description={self._description!r}")
         if self._path:
-            argl.append(f"path={repr(self._path)}")
+            argl.append(f"path={self._path!r}")
         if self._cite_module:
-            argl.append(f"cite_module={repr(self._cite_module)}")
+            argl.append(f"cite_module={self._cite_module!r}")
 
         if argl:
             args = ", ".join(argl)
@@ -130,7 +133,7 @@ class Citation:
     def cites_module(self) -> bool | None:
         if not self.path:
             return None
-        return not (":" in self.path)
+        return ":" not in self.path
 
     @property
     def module(self) -> str | None:
@@ -239,7 +242,7 @@ class DueCreditCollector:
             raise ValueError("Must be a string")
 
     def _load_bib(self, src: str) -> None:
-        lgr.debug("Loading %s" % src)
+        lgr.debug(f"Loading {src}")
 
     # # TODO: figure out what would be the optimal use for the __call__
     # def __call__(self, *args, **kwargs):
@@ -255,7 +258,7 @@ class DueCreditCollector:
         # TODO: if cite is invoked but no path is provided -- we must figure it out
         # I guess from traceback, otherwise how would we know later to associate it
         # with modules???
-        path = kwargs.get("path", None)
+        path = kwargs.get("path")
         if path is None:
             raise ValueError("path must be provided")
 
@@ -279,7 +282,7 @@ class DueCreditCollector:
 
         # TODO: theoretically version shouldn't differ if we don't preload previous results
         if not citation.version:
-            version = kwargs.get("version", None)
+            version = kwargs.get("version")
 
             if not version and citation.path:
                 modname = citation.path.split(".", 1)[0]
@@ -318,7 +321,7 @@ class DueCreditCollector:
             # main logic -- assess default and if get to the next one if
             # given argument is not present
             if not ((len(fargs) > argpos) or (kwarg in fkwargs)):
-                if not ("DC_DEFAULT" in values):
+                if "DC_DEFAULT" not in values:
                     # if value was specified but not provided and not default
                     # conditions are not satisfied
                     return False
@@ -339,7 +342,7 @@ class DueCreditCollector:
                     value = getattr(value, attr)
 
             # Value is present but not matching
-            if not (value in values):
+            if value not in values:
                 return False
 
         # if checks passed -- we must have matched conditions
@@ -400,12 +403,12 @@ class DueCreditCollector:
 
         def func_wrapper(func):
             conditions = kwargs.pop("conditions", {})
-            path = kwargs.get("path", None)
+            path = kwargs.get("path")
             if not path:
                 # deduce path from the actual function which was decorated
                 # TODO: must include class name  but can't !!!???
                 modname = func.__module__
-                path = kwargs["path"] = "{}:{}".format(modname, func.__name__)
+                path = kwargs["path"] = f"{modname}:{func.__name__}"
             else:
                 # TODO: we indeed need to separate path logic outside
                 modname = path.split(":", 1)[0]
@@ -419,9 +422,7 @@ class DueCreditCollector:
             # TODO: might make use of inspect.getmro
             # see e.g.
             # http://stackoverflow.com/questions/961048/get-class-that-defined-method
-            lgr.debug(
-                "Decorating func {} within module {}".format(func.__name__, modname)
-            )
+            lgr.debug(f"Decorating func {func.__name__} within module {modname}")
             # TODO: unittest for all the __version__ madness
 
             # TODO: check if we better use wrapt module which provides superior "correctness"
@@ -434,7 +435,7 @@ class DueCreditCollector:
                     ):
                         self.cite(*args, **kwargs)
                 except Exception as e:
-                    lgr.warning("Failed to cite due to {}".format(e))
+                    lgr.warning(f"Failed to cite due to {e}")
                 return func(*fargs, **fkwargs)
 
             cite_wrapper.__duecredited__ = func
@@ -446,9 +447,9 @@ class DueCreditCollector:
     def __repr__(self) -> str:
         argl = []
         if self.citations:
-            argl.append(f"citations={repr(self.citations)}")
+            argl.append(f"citations={self.citations!r}")
         if self._entries:
-            argl.append(f"entries={repr(self._entries)}")
+            argl.append(f"entries={self._entries!r}")
 
         if argl:
             args = ", ".join(argl)
@@ -458,9 +459,7 @@ class DueCreditCollector:
 
     @never_fail
     def __str__(self) -> str:
-        return self.__class__.__name__ + " {:d} entries, {:d} citations".format(
-            len(self._entries), len(self.citations)
-        )
+        return f"{self.__class__.__name__} {len(self._entries)} entries, {len(self.citations)} citations"
 
 
 # TODO: redo heavily -- got very messy
