@@ -6,8 +6,8 @@
 #   copyright and license terms.
 #
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""Importer which would also call decoration on a module upon import
-"""
+"""Importer which would also call decoration on a module upon import"""
+
 from __future__ import annotations
 
 __docformat__ = "restructuredtext"
@@ -131,7 +131,7 @@ class DueCreditInjector:
         self,
         modulename: str,
         obj: str | None,
-        entry: 'Doi' | 'BibTeX' | 'Url',
+        entry: Doi | BibTeX | Url,
         min_version=None,
         max_version=None,
         **kwargs: Any,
@@ -160,7 +160,7 @@ class DueCreditInjector:
             self._entry_records[modulename][obj] = []
         obj_entries = self._entry_records[modulename][obj]
         if "path" not in kwargs:
-            kwargs["path"] = modulename + ((":%s" % obj) if obj else "")
+            kwargs["path"] = modulename + ((f":{obj}") if obj else "")
         obj_entries.append(
             {
                 "entry": entry,
@@ -189,9 +189,9 @@ class DueCreditInjector:
                 inj_mod_name_full, fromlist=["duecredit.injections"]
             )
         except Exception as e:
-            if os.environ.get("DUECREDIT_ALLOW_FAIL", False):
+            if os.environ.get("DUECREDIT_ALLOW_FAIL", None):
                 raise
-            raise RuntimeError("Failed to import {}: {!r}".format(inj_mod_name, e))
+            raise RuntimeError(f"Failed to import {inj_mod_name}: {e!r}") from e
         # TODO: process min/max_versions etc
         assert hasattr(inj_mod, "inject")
         lgr.log(3, "Calling injector of %s", inj_mod_name_full)
@@ -227,7 +227,7 @@ class DueCreditInjector:
         try:
             mod = sys.modules[mod_name]
         except KeyError:
-            lgr.warning("Failed to access module %s among sys.modules" % mod_name)
+            lgr.warning(f"Failed to access module {mod_name} among sys.modules")
             return
 
         # go through the known entries and register them within the collector, and
@@ -240,9 +240,7 @@ class DueCreditInjector:
                 try:
                     parent, obj_name, obj = find_object(mod, obj_path)
                 except (KeyError, AttributeError) as e:
-                    lgr.warning(
-                        "Could not find {} in module {}: {}".format(obj_path, mod, e)
-                    )
+                    lgr.warning(f"Could not find {obj_path} in module {mod}: {e}")
                     continue
 
             # there could be multiple per func
@@ -360,7 +358,7 @@ class DueCreditInjector:
             if retrospect:
                 lgr.debug("Considering previously loaded %d modules", len(sys.modules))
                 # operate on keys() (not iterator) since we might end up importing delayed injection modules etc
-                for mod_name in sys.modules.keys():
+                for mod_name in sys.modules:
                     self.process(sys.modules[mod_name])
 
             lgr.debug("Assigning our importer")
@@ -453,9 +451,9 @@ class DueCreditInjector:
         try:
             if self._active:
                 self.deactivate()
-        except:  # noqa: E722, B001
+        except:  # noqa: E722
             pass
         try:
-            super(self.__class__, self).__del__()  # type: ignore
-        except:  # noqa: E722, B001
+            super(self.__class__, self).__del__()  # type: ignore[misc]
+        except:  # noqa: E722
             pass
