@@ -6,8 +6,8 @@
 #   copyright and license terms.
 #
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
-"""Automatic injection of bibliography entries for pandas module
-"""
+"""Automatic injection of bibliography entries for pandas module"""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
