@@ -11,7 +11,7 @@ from __future__ import annotations
 # Just for testing of robust operation
 import os
 
-if "DUECREDIT_TEST_EARLY_IMPORT_ERROR" in os.environ.keys():
+if "DUECREDIT_TEST_EARLY_IMPORT_ERROR" in os.environ:
     raise ImportError("DUECREDIT_TEST_EARLY_IMPORT_ERROR")
 
 from collections import defaultdict
@@ -72,9 +72,8 @@ def import_doi(doi: str, sleep: float = 0.5, retries: int = 10) -> str:
     if not bibtex.startswith("@"):
         raise ValueError(
             "Query %(url)s for BibTeX for a DOI %(doi)s (wrong doi?) has failed. "
-            "Response code %(status_code)d. "
+            "Response code %(status_code)d. " % locals()
             # 'BibTeX response was: %(bibtex)s'
-            % locals()
         )
     if not exists(cached):
         cache_dir = dirname(cached)
@@ -87,11 +86,7 @@ def import_doi(doi: str, sleep: float = 0.5, retries: int = 10) -> str:
 
 def _is_contained(toppath: str, subpath: str) -> bool:
     if ":" not in toppath:
-        return (
-            (toppath == subpath)
-            or (subpath.startswith(toppath + "."))
-            or (subpath.startswith(toppath + ":"))
-        )
+        return toppath == subpath or subpath.startswith((toppath + ".", toppath + ":"))
     else:
         return subpath.startswith(toppath + ".")
 
@@ -155,10 +150,10 @@ class Output:
             if (
                 all_
                 or any(
-                    filter(lambda x: x.cite_module, package_citations)  # type: ignore
+                    filter(lambda x: x.cite_module, package_citations)  # type: ignore[attr-defined,arg-type]
                 )
                 or any(
-                    filter(lambda x: _is_contained(package, x), cited_modobj)  # type: ignore
+                    filter(lambda x: _is_contained(package, x), cited_modobj)  # type: ignore[arg-type]
                 )
             ):
                 continue
@@ -176,7 +171,7 @@ class TextOutput(Output):
     def __init__(self, fd, collector, style=None) -> None:
         super().__init__(fd, collector)
         self.style = style
-        if "DUECREDIT_STYLE" in os.environ.keys():
+        if "DUECREDIT_STYLE" in os.environ:
             self.style = os.environ["DUECREDIT_STYLE"]
         else:
             self.style = "harvard1"
@@ -202,7 +197,7 @@ class TextOutput(Output):
         pmo.update(objects)
 
         # get all the paths
-        paths = sorted(list(pmo))
+        paths = sorted(pmo)
         # get all the entry_keys in order
         entry_keys = [c.entry.key for p in paths for c in pmo[p]]
         # make a dictionary entry_key -> citation_nr
@@ -241,7 +236,7 @@ class TextOutput(Output):
             for path in paths:
                 for cit in pmo[path]:
                     # 'import Citation / assert type(cit) is Citation' would pollute environment
-                    ek = cit.entry.key  # type: ignore
+                    ek = cit.entry.key
                     if ek not in printed_keys:
                         self.fd.write(f"\n[{citation_nr[ek]}] ")
                         self.fd.write(get_text_rendering(cit.entry, style=self.style))
@@ -268,7 +263,7 @@ def get_bibtex_rendering(entry: DueCreditEntry) -> BibTeX:
     elif isinstance(entry, BibTeX):
         return entry
     else:
-        raise ValueError("Have no clue how to get bibtex out of %s" % entry)
+        raise ValueError(f"Have no clue how to get bibtex out of {entry}")
 
 
 def condition_bibtex(bibtex: str) -> bytes:
@@ -294,16 +289,33 @@ def condition_bibtex(bibtex: str) -> bytes:
     return bibtex.encode("utf-8")
 
 
-def format_bibtex(bibtex_entry: BibTeX, style: str = "harvard1") -> str:
+def format_bibtex(
+    bibtex_entry: BibTeX, style: str = "harvard1", formatter: str = "plain"
+) -> str:
+    """Format a BibTeX entry as a citation string.
+
+    Parameters
+    ----------
+    bibtex_entry : BibTeX
+        The BibTeX entry to format.
+    style : str, optional
+        Citation style (default: "harvard1").
+    formatter : str, optional
+        Output format: "plain" (default), "html", or "rst".
+
+    Returns
+    -------
+    str
+        Formatted citation string.
+    """
     try:
         import citeproc as cp
         from citeproc.source.bibtex import BibTeX as cpBibTeX
     except ImportError as e:
         raise RuntimeError(
             "For formatted output we need citeproc and all of its dependencies "
-            "(such as lxml) but there is a problem while importing citeproc: %s"
-            % str(e)
-        )
+            f"(such as lxml) but there is a problem while importing citeproc: {e}"
+        ) from e
     decode_exceptions: tuple[type[Exception], ...]
     try:
         from citeproc.source.bibtex.bibparse import BibTeXDecodeError
@@ -330,7 +342,7 @@ def format_bibtex(bibtex_entry: BibTeX, style: str = "harvard1") -> str:
                 # we should be able to provide encoding argument
                 bib_source = cpBibTeX(fname, encoding="utf-8")
         except Exception as e:
-            msg = "Failed to process BibTeX file {}: {}.".format(fname, e)
+            msg = f"Failed to process BibTeX file {fname}: {e}."
             if "unexpected keyword argument" in str(e):
                 citeproc_version = external_versions["citeproc"]
                 if isinstance(citeproc_version, Version) and citeproc_version < Version(
@@ -341,14 +353,23 @@ def format_bibtex(bibtex_entry: BibTeX, style: str = "harvard1") -> str:
             else:
                 err = str(e)
             lgr.error(msg)
-            return "ERRORED: %s" % err
+            return f"ERRORED: {err}"
         finally:
             # return warnings back
             warnings.filters = old_filters
         bib_style = cp.CitationStylesStyle(style, validate=False)
-        # TODO: specify which tags of formatter we want
+        formatters = {
+            f: getattr(cp.formatter, f)
+            for f in dir(cp.formatter)
+            if not f.startswith("_")
+        }
+        if formatter not in formatters:
+            raise ValueError(
+                f"Unknown formatter {formatter!r}. "
+                f"Valid options: {', '.join(formatters.keys())}"
+            )
         bibliography = cp.CitationStylesBibliography(
-            bib_style, bib_source, cp.formatter.plain
+            bib_style, bib_source, formatters[formatter]
         )
         citation = cp.Citation([cp.CitationItem(key)])
         bibliography.register(citation)
@@ -400,7 +421,7 @@ class BibTeXOutput(Output):
         pmo.update(objects)
 
         # get all the paths
-        paths = sorted(list(pmo))
+        paths = sorted(pmo)
 
         entries = []
         for path in paths:
