@@ -3,7 +3,7 @@ from typing import Any
 
 def testfunc1(arg1: Any, kwarg1: Any = None) -> str:
     """custom docstring"""
-    return "testfunc1: {}, {}".format(arg1, kwarg1)
+    return f"testfunc1: {arg1}, {kwarg1}"
 
 
 class TestClass1:
@@ -11,7 +11,7 @@ class TestClass1:
 
     def testmeth1(self, arg1: Any, kwarg1: Any = None) -> str:
         """custom docstring"""
-        return "TestClass1.testmeth1: {}, {}".format(arg1, kwarg1)
+        return f"TestClass1.testmeth1: {arg1}, {kwarg1}"
 
 
 class TestClass12:
@@ -22,4 +22,4 @@ class TestClass12:
 
         def testmeth1(self, arg1: Any, kwarg1: Any = None) -> str:
             """custom docstring"""
-            return "TestClass12.Embed.testmeth1: {}, {}".format(arg1, kwarg1)
+            return f"TestClass12.Embed.testmeth1: {arg1}, {kwarg1}"
