@@ -8,6 +8,8 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 from __future__ import annotations
 
+import functools
+import operator
 import os
 from typing import TYPE_CHECKING, Any
 
@@ -120,7 +122,7 @@ def test_dcite_method() -> None:
             return "load"
 
         class SomeClass:
-            @due.dcite("XXX0", path="someclass:method")  # type: ignore
+            @due.dcite("XXX0", path="someclass:method")  # type: ignore[attr-defined]
             def method(self, arg1: str, kwarg2: str = "blah") -> str:
                 """docstring"""
                 assert arg1 == "magical"
@@ -161,8 +163,8 @@ def test_dcite_method() -> None:
 
         class SomeClass2:
             # Used to test for classes that are not instantiated
-            @due.dcite("XXX0", path="some.module.without.method")  # type: ignore
-            def method2(self, arg1, kwarg2="blah"):  # noqa: U100
+            @due.dcite("XXX0", path="some.module.without.method")  # type: ignore[attr-defined]
+            def method2(self, arg1, kwarg2="blah"):
                 assert arg1 == "magical"
                 return "load"
 
@@ -258,7 +260,7 @@ def test_dcite_match_conditions_function() -> None:
     def method(arg1: str, kwarg2: str = "blah") -> str:
         """docstring"""
         assert arg1 == "magical"
-        return "load %s" % kwarg2
+        return f"load {kwarg2}"
 
     _test_dcite_match_conditions(due, method, "callable")
 
@@ -285,7 +287,7 @@ def test_dcite_match_conditions_method() -> None:
         def method(self, arg1: str, kwarg2: str = "blah") -> str:
             """docstring"""
             assert arg1 == "magical"
-            return "load %s" % kwarg2
+            return f"load {kwarg2}"
 
     citeable = Citeable(param="paramvalue")
     _test_dcite_match_conditions(due, citeable.method, "obj.callable")
@@ -313,9 +315,11 @@ def test_get_output_handler_method(tmpdir: py.path.local, monkeypatch) -> None:
 
 def test_collectors_uniform_api() -> None:
     def get_api(objs) -> list[str]:
-        return [
+        return [  # type: ignore[var-annotated]
             x
-            for x in sorted(sum((dir(obj) for obj in objs), []))
+            for x in sorted(
+                functools.reduce(operator.iadd, (dir(obj) for obj in objs), [])
+            )
             if not x.startswith("_") or x in "__call__"
         ]
 
