@@ -18,7 +18,7 @@ import pytest
 
 from duecredit.collector import DueCreditCollector
 from duecredit.entries import Doi
-import duecredit.tests.mod as mod
+from duecredit.tests import mod
 
 from .. import __version__
 from ..injections.injector import (
@@ -65,7 +65,7 @@ class TestActiveInjector:
             "duecredit.tests.mod",
             func,
             Doi("1.2.3.4"),
-            description="Testing %s" % func,
+            description=f"Testing {func}",
             min_version="0.1",
             max_version="1.0",
             tags=["implementation", "very custom"],
@@ -81,7 +81,7 @@ class TestActiveInjector:
         assert len(self.due._entries) == 1  # we should get an entry now
         assert len(self.due.citations) == 0  # but not yet a citation
 
-        import duecredit.tests.mod as mod
+        from duecredit.tests import mod
 
         _, _, obj = find_object(mod, func)
         assert obj.__duecredited__  # we wrapped
@@ -92,12 +92,11 @@ class TestActiveInjector:
         exec('ret = %s(None, "somevalue")' % (func_call or func), globals_, locals_)
         # TODO: awkwardly 'ret' is not found in the scope while running pytest
         # under python3.4, although present in locals()... WTF?
-        assert locals_["ret"] == "%s: None, somevalue" % func
+        assert locals_["ret"] == f"{func}: None, somevalue"
         assert len(self.due._entries) == 1
         assert len(self.due.citations) == 1
 
-        # TODO: there must be a cleaner way to get first value
-        citation = list(self.due.citations.values())[0]
+        citation = next(iter(self.due.citations.values()))
         # TODO: ATM we don't allow versioning of the submodules -- we should
         # assert_equal(citation.version, '0.5')
         # ATM it will be the duecredit's version
@@ -112,7 +111,7 @@ class TestActiveInjector:
             "duecredit.tests.mod",
             func,
             Doi("1.2.3.4"),
-            description="Testing %s" % func,
+            description=f"Testing {func}",
             min_version="0.1",
             max_version="1.0",
             tags=["implementation", "very custom"],
@@ -122,7 +121,7 @@ class TestActiveInjector:
             "duecredit.tests.mod",
             func,
             Doi("1.2.3.5"),
-            description="Testing %s" % func,
+            description=f"Testing {func}",
             min_version="0.1",
             max_version="1.0",
             tags=["implementation", "very custom"],
@@ -138,7 +137,7 @@ class TestActiveInjector:
         assert len(self.due._entries) == 2  # we should get two entries now
         assert len(self.due.citations) == 0  # but not yet a citation
 
-        import duecredit.tests.mod as mod
+        from duecredit.tests import mod
 
         _, _, obj = find_object(mod, func)
         assert obj.__duecredited__  # we wrapped
@@ -149,12 +148,11 @@ class TestActiveInjector:
         exec('ret = %s(None, "somevalue")' % (func_call or func), globals_, locals_)
         # TODO: awkwardly 'ret' is not found in the scope while running pytest
         # under python3.4, although present in locals()... WTF?
-        assert locals_["ret"] == "%s: None, somevalue" % func
+        assert locals_["ret"] == f"{func}: None, somevalue"
         assert len(self.due._entries) == 2
         assert len(self.due.citations) == 2
 
-        # TODO: there must be a cleaner way to get first value
-        citation = list(self.due.citations.values())[0]
+        citation = next(iter(self.due.citations.values()))
         # TODO: ATM we don't allow versioning of the submodules -- we should
         # assert_equal(citation.version, '0.5')
         # ATM it will be the duecredit's version
@@ -193,7 +191,7 @@ class TestActiveInjector:
             # We do have injections for scipy
             import scipy  # noqa: F401
         except ImportError as e:
-            pytest.skip("scipy was not found: {}".format(e))
+            pytest.skip(f"scipy was not found: {e}")
 
     def test_import_mvpa2_suite(self) -> None:
         if not _have_mvpa2:
@@ -304,8 +302,8 @@ def test_injector_del() -> None:
         assert __builtin__.__import__ is not orig__import__
         assert inj._orig_import is not None
         del inj  # delete active but not used
-        inj = None  # type: ignore  # noqa: F841
-        __builtin__.__import__ = None  # type: ignore
+        inj = None  # type: ignore[assignment]  # noqa: F841
+        __builtin__.__import__ = None  # type: ignore[assignment]
         # /\ We need to do that since otherwise gc will not pick up inj
         gc.collect()  # To cause __del__
         assert __builtin__.__import__ is orig__import__
@@ -336,8 +334,8 @@ def test_injector_delayed_del() -> None:
         inj2.activate(retrospect=False)
         assert __builtin__.__import__ is not orig__import__
         assert inj2._orig_import is not None
-        del inj  # type: ignore
-        inj = None  # type: ignore  # noqa: F841
+        del inj
+        inj = None  # type: ignore[assignment]  # noqa: F841
         gc.collect()  # To cause __del__
         assert (
             __builtin__.__import__ is not orig__import__
