@@ -84,7 +84,7 @@ def test_pickleoutput(tmpdir) -> None:
     for collector in collectors:
         pickler = PickleOutput(collector, fn=tempfile)
         assert pickler.fn == tempfile
-        assert pickler.dump() is None  # type: ignore
+        assert pickler.dump() is None  # type: ignore[func-returns-value]
 
         with open(tempfile, "rb") as f:
             collector_loaded = pickle.load(f)
@@ -294,9 +294,9 @@ def test_text_output() -> None:
     strio = StringIO()
     TextOutput(strio, collector).dump(tags=["*"])
     value = strio.getvalue()
-    assert "0 packages cited" in value, "value was %s" % value
-    assert "0 modules cited" in value, "value was %s" % value
-    assert "0 functions cited" in value, "value was %s" % value
+    assert "0 packages cited" in value, f"value was {value}"
+    assert "0 modules cited" in value, f"value was {value}"
+    assert "0 functions cited" in value, f"value was {value}"
 
     # but it should be cited if cite_module=True
     collector = DueCreditCollector()
@@ -305,9 +305,9 @@ def test_text_output() -> None:
     strio = StringIO()
     TextOutput(strio, collector).dump(tags=["*"])
     value = strio.getvalue()
-    assert "1 package cited" in value, "value was %s" % value
-    assert "0 modules cited" in value, "value was %s" % value
-    assert "0 functions cited" in value, "value was %s" % value
+    assert "1 package cited" in value, f"value was {value}"
+    assert "0 modules cited" in value, f"value was {value}"
+    assert "0 functions cited" in value, f"value was {value}"
 
     # in this case, we should be citing the package since we are also citing a
     # submodule
@@ -318,10 +318,10 @@ def test_text_output() -> None:
     strio = StringIO()
     TextOutput(strio, collector).dump(tags=["*"])
     value = strio.getvalue()
-    assert "1 package cited" in value, "value was %s" % value
-    assert "1 module cited" in value, "value was %s" % value
-    assert "0 functions cited" in value, "value was %s" % value
-    assert "Halchenko, Y.O." in value, "value was %s" % value
+    assert "1 package cited" in value, f"value was {value}"
+    assert "1 module cited" in value, f"value was {value}"
+    assert "0 functions cited" in value, f"value was {value}"
+    assert "Halchenko, Y.O." in value, f"value was {value}"
     assert value.strip().endswith("Frontiers in Neuroinformatics, 6(22).")
 
     # in this case, we should be citing the package since we are also citing a
@@ -334,12 +334,12 @@ def test_text_output() -> None:
     strio = StringIO()
     TextOutput(strio, collector).dump(tags=["*"])
     value = strio.getvalue()
-    assert "1 package cited" in value, "value was %s" % value
-    assert "1 module cited" in value, "value was %s" % value
-    assert "0 functions cited" in value, "value was %s" % value
-    assert "Halchenko, Y.O." in value, "value was %s" % value
-    assert "[1, 2]" in value, "value was %s" % value
-    assert "[3]" not in value, "value was %s" % value
+    assert "1 package cited" in value, f"value was {value}"
+    assert "1 module cited" in value, f"value was {value}"
+    assert "0 functions cited" in value, f"value was {value}"
+    assert "Halchenko, Y.O." in value, f"value was {value}"
+    assert "[1, 2]" in value, f"value was {value}"
+    assert "[3]" not in value, f"value was {value}"
 
 
 def test_text_output_dump_formatting() -> None:
@@ -496,9 +496,9 @@ def test_bibtex_output() -> None:
     strio = StringIO()
     BibTeXOutput(strio, collector).dump(tags=["*"])
     value = strio.getvalue()
-    assert (
-        value.strip() == _sample_bibtex.strip() + _sample_bibtex2.rstrip()
-    ), f"Value was {value}"
+    assert value.strip() == _sample_bibtex.strip() + _sample_bibtex2.rstrip(), (
+        f"Value was {value}"
+    )
 
     # check the we output only unique bibtex entries
     collector.cite(entry2, path="package")
@@ -539,9 +539,9 @@ def _generate_sample_bibtex() -> str:
         ("year", year),
     ]
 
-    sample_bibtex = "@ARTICLE{%s,\n" % key
+    sample_bibtex = f"@ARTICLE{{{key},\n"
     for string, value in elements:
-        sample_bibtex += "{}={{{}}},\n".format(string, value)
+        sample_bibtex += f"{string}={{{value}}},\n"
     sample_bibtex += "}"
     return sample_bibtex
 
@@ -637,6 +637,42 @@ def test_format_bibtex_with_utf_characters() -> None:
     )
 
 
+def test_format_bibtex_html_formatter() -> None:
+    """Test that html formatter produces HTML tags for styled text."""
+    bibtex_article = (
+        "@article{Test_2020,\n"
+        "title={Test Title},\n"
+        "journal={Nature Methods},\n"
+        "author={Smith, John},\n"
+        "year={2020}\n}"
+    )
+    result = format_bibtex(BibTeX(bibtex_article), formatter="html")
+    # Journal name should be italicized with <i> tags
+    assert "<i>" in result
+    assert "Nature Methods" in result
+
+
+def test_format_bibtex_rst_formatter() -> None:
+    """Test that rst formatter produces RST markup for styled text."""
+    bibtex_article = (
+        "@article{Test_2020,\n"
+        "title={Test Title},\n"
+        "journal={Nature Methods},\n"
+        "author={Smith, John},\n"
+        "year={2020}\n}"
+    )
+    result = format_bibtex(BibTeX(bibtex_article), formatter="rst")
+    # Journal name should use RST emphasis
+    assert ":emphasis:" in result
+
+
+def test_format_bibtex_invalid_formatter() -> None:
+    """Test that invalid formatter raises ValueError."""
+    bibtex = "@misc{test, title={Test}, author={Test}, year={2020}}"
+    with pytest.raises(ValueError, match="Unknown formatter"):
+        format_bibtex(BibTeX(bibtex), formatter="invalid")
+
+
 def test_is_contained() -> None:
     toppath = "package"
     assert _is_contained(toppath, "package.module")
